Learn R Programming

IndiAPIs (version 0.1.0)

get_india_unemployment: Get India's Unemployment Rate from World Bank

Description

Retrieves India's total unemployment rate as a percentage of the total labor force for the years 2010 to 2022 using the World Bank Open Data API. The indicator used is SL.UEM.TOTL.ZS.

Usage

get_india_unemployment()

Arguments

Value

A tibble with the following columns:

  • indicator: Indicator name

  • country: Country name (India)

  • year: Year of the data (integer)

  • value: Unemployment rate as percentage

Details

This function sends a GET request to the World Bank API. If the API request fails or returns an error status code, the function returns NULL with an informative message.

See Also

Examples

Run this code
if (FALSE) {
  unemployment_data <- get_india_unemployment()
  print(unemployment_data)
}

Run the code above in your browser using DataLab